
#' plot_friendlyts

#' plot_friendlyts
#' @param x object of class tbl_friendlyts
#' @param target target character
#' @param fromDate fromDate
#' @param toDate toDate
#' @param timeResolution timeResolution
#' @param tzone tzone
#' @param name name
#' @param width_mm width_mm
#' @param height_mm height_mm
#' @param y_name name on the y-axis
#' @param DESKTOP boolean
#' @keywords friendlyts
#' @export
#' @examples
#' \dontrun{
#' plot_friendlyts()
#' }
plot_tbl_friendlyts <- function(x,target,fromDate=NULL,toDate=NULL,timeResolution=NULL,tzone="UTC",name=NULL,width_mm=200,height_mm=200,y_name="Y-axis",DESKTOP=FALSE){

  nb_target <- length(target)
  if (nb_target>0) {

    # sub-period
    if (!is.null(fromDate) && !is.null(toDate) && !is.null(timeResolution)) {
       tmp <- sub_period(tbl_fts=x,fromDate=fromDate,toDate=toDate,timeResolution=timeResolution,tzone=tzone)
    } else tmp <- x

    tmp <- dfts(tbl_fts=tmp,timeResolution=timeResolution,tzone=tzone)
    tmp <- tibble::as_tibble(dplyr::select(tmp,c("date",target)))

    # gather
    df <- tmp %>% tidyr::gather("variable", "value", -"date")


    #start plot
    if (!(DESKTOP)) {

      filename <- file_friendlyts(name=name,format= "tiff")

      grDevices::tiff(filename = filename, width = width_mm, height = height_mm,
            units = "mm", pointsize = 12,
            compression = "lzw",
            bg = "transparent", res = 300)

    } else grDevices::dev.new()

    #plot
    p <- ggplot2::ggplot(df, ggplot2::aes(date)) +
      ggplot2::geom_line(ggplot2::aes(y = value, colour = variable)) +
      ggplot2::labs(x = "date",y = y_name)

    print(p)

    if (!(DESKTOP)) {
      grDevices::dev.off()
      return(filename)
    } else {
      return(TRUE)
    }

  } else stop("no target")



}
